function asa = getAdditionalSubmitArguments(props)

% https://research.csc.fi/taito-batch-jobs
% https://research.csc.fi/taito-constructing-a-batch-job-file

% Copyright 2010-2015 The MathWorks, Inc.

asa = '';

[~,flag] = strtok(props.MatlabArguments,'p');
if strcmp(flag,'parallel')
    w = props.NumberOfTasks;
else
    w = 1;
end

% The following are not supported below, though could be added with
%
%   ClusterInfo.setUserDefinedOptions()
%
%
% --cpus-per-task (should always be 1)
% --nodes (though we support --ntasks-per-node/-n)
% --mem (though we support --mem-per-cpu)
%

% Number of nodes/cores
ppn = ClusterInfo.getProcsPerNode();
if isempty(ppn)==false
    % Don't request more cores/node than workers
    ppn = min(w,ppn);
    asa = sprintf('%s -n %d --ntasks-per-node=%d',asa,w,ppn);
else
    asa = sprintf('%s -n %d',asa,w);
end


%% REQUIRED


%% OPTIONAL

% Walltime
wt = ClusterInfo.getWallTime();
if isempty(wt)==false
    asa = [asa ' -t ' wt];
end

% Partition
gpu = ClusterInfo.getUseGpu();
if gpu==true
    % MW: How should the user request gpulong and gputest?
    % gpu     : 3 days, up to 36 nodes
    % gpulong : 14 days, up to 10 nodes
    % gputest : 15 minutes, up to 2 nodes
    ngpus = ClusterInfo.getGpusPerNode();
    if ngpus==2
        asa = [asa ' -p gpu --gres=gpu:2 --exclusive'];
    else
        if isempty(ngpus)
            ngpus = 1;
        end
        asa = [asa ' -p gpu --gres=gpu:' num2str(ngpus)];
    end
else
    qn = ClusterInfo.getQueueName();
    if isempty(qn)==false
        asa = [asa ' --partition=' qn];
    end
end

% Physical Memory used by a single core
mu = ClusterInfo.getMemUsage();
if isempty(mu)==false
    % Per CPU (in MB)
    asa = [asa ' --mem-per-cpu=' mu];
end

% Architecture
a = ClusterInfo.getArch();
if isempty(a)==false
    asa = [asa ' --constraint=' a];
end

% Reservation
res = ClusterInfo.getReservation();
if isempty(res)==false
    asa = [asa ' --reservation=' res];
end

% Email notification
ea = ClusterInfo.getEmailAddress();
if isempty(ea)==false
    % User wants to be emailed the job status
    asa = [asa ' --mail-type=ALL --mail-user=' ea];
end

% Every job is going to require a certain number of MDCS licenses.
% Specification of MDCS licenses which must be allocated to this
% job.  The /etc/slurm/slurm.conf file must list
%
%   # MDCS licenses
%   Licenses=mdcs:500
%
% And then call
%
%   % scontrol reconfigure 
%
asa = sprintf('%s --licenses=mdcs:%d',asa,w);

% Catch-all
udo = ClusterInfo.getUserDefinedOptions();
if isempty(udo)==false
    asa = [asa ' ' udo];
end

asa = strtrim(asa);
